@@ -186,7 +186,7 @@ func run(ctx context.Context) (err error) {
 	}
 
 	var envVars map[string]string = nil
-	envFlags := flag.GetStringArray(ctx, "env")
+	envFlags := flag.GetStringSlice(ctx, "env")
 	if len(envFlags) > 0 {
 		envVars, err = cmdutil.ParseKVStringsToMap(envFlags)
 		if err != nil {
